==> alfred-ui-native-components-0.0.153.tgz: package/ui/widgets/details/thermostat/components/selectors/speedSelector/index.tsx <==
import React, { FC, useEffect, useState } from 'react';
import { View } from 'react-native';
import DropDownPicker, { ItemType } from 'react-native-dropdown-picker';
import { SpeedsInfoTextModel } from '../../../../widgetDetailModels';
import { styles } from '../styles';

interface Props {
  speedsList: number[],
  speedsTexts: SpeedsInfoTextModel,
  selectedItem: string,
  onSelectItem: (item: ItemType<number>) => void;
  isLoading: boolean;
}

interface ListItem {
  label: string,
  value: number
}
export const thermostatFanModes = {
  OFF: '0',
  AUTO: '1',
  LOW: '2',
  MEDIUM: '3',
  FAST: '4',
};

export const SpeedSelector: FC<Props> = ({
  speedsList,
  speedsTexts,
  selectedItem,
  onSelectItem,
  isLoading,
}) => {
  const infoTextFromNumber = {
    [thermostatFanModes.OFF]: speedsTexts.off || '',
    [thermostatFanModes.AUTO]: speedsTexts.auto || '',
    [thermostatFanModes.LOW]: speedsTexts.low || '',
    [thermostatFanModes.MEDIUM]: speedsTexts.medium || '',
    [thermostatFanModes.FAST]: speedsTexts.fast || '',
  };
  const speedsTextList: ListItem[] = speedsList.map(
    (speed: number) => ({ label: infoTextFromNumber[speed], value: speed }),
  );
  
  const [open, setOpen] = useState<boolean>(false);
  const [value, setValue] = useState<number>(0);
  const [items, setItems] = useState<ListItem[]>(speedsTextList);
  
  useEffect(() => {
    const value = speedsList.find((item) => item === parseInt(selectedItem));
    value && setValue(value);
  }, [selectedItem]);

  return (
    <View>
      <DropDownPicker
        listMode='SCROLLVIEW'
        disabled={isLoading}
        placeholder='Select mode'
        open={open}
        onSelectItem={onSelectItem}
        value={value}
        items={items}
        setOpen={setOpen}
        setValue={setValue}
        setItems={setItems}
        dropDownDirection={'TOP'}
        itemSeparator={true}
        listItemLabelStyle={styles.modeThermostatItemLabel}
        listItemContainerStyle={styles.modeThermostatItemContainer}
        showArrowIcon={false}
        showTickIcon={false}
        itemSeparatorStyle={styles.modeThermostatItemSeparator}
        dropDownContainerStyle={styles.modeThermostatDropDownContainer}
        textStyle={styles.modeThermostatText}
        disabledStyle={styles.modeThermostatDisabled}
        containerStyle={styles.modeThermostatContainer}
        style={styles.modeThermostatSelectButton}
      />
    </View>
  );
};

==> alfred-ui-native-components-0.0.166.tgz: package/ui/widgets/details/thermostat/components/selectors/speedSelector/index.tsx <==
import React, { FC, useEffect, useState } from 'react';
import { View } from 'react-native';
import DropDownPicker, { ItemType } from 'react-native-dropdown-picker';
import { SpeedsInfoTextModel } from '../../../../widgetDetailModels';
import { styles } from '../styles';

interface Props {
  speedsList: number[],
  speedsTexts: SpeedsInfoTextModel,
  selectedItem: string,
  onSelectItem: (item: ItemType<number>) => void;
  isLoading: boolean;
}

interface ListItem {
  label: string,
  value: number
}
export const thermostatFanModes = {
  OFF: '0',
  AUTO: '1',
  LOW: '2',
  MEDIUM: '3',
  FAST: '4',
};

export const SpeedSelector: FC<Props> = ({
  speedsList,
  speedsTexts,
  selectedItem,
  onSelectItem,
  isLoading,
}) => {
  const infoTextFromNumber = {
    [thermostatFanModes.OFF]: speedsTexts.off || '',
    [thermostatFanModes.AUTO]: speedsTexts.auto || '',
    [thermostatFanModes.LOW]: speedsTexts.low || '',
    [thermostatFanModes.MEDIUM]: speedsTexts.medium || '',
    [thermostatFanModes.FAST]: speedsTexts.fast || '',
  };
  const speedsTextList: ListItem[] = speedsList.map(
    (speed: number) => ({ label: infoTextFromNumber[speed], value: speed }),
  );
  
  const [open, setOpen] = useState<boolean>(false);
  const [value, setValue] = useState<number>(0);
  const [items, setItems] = useState<ListItem[]>(speedsTextList);
  
  useEffect(() => {
    const value = speedsList.find((item) => item === parseInt(selectedItem));
    value && setValue(value);
  }, [selectedItem]);

  return (
    <View>
      <DropDownPicker
        listMode='SCROLLVIEW'
        disabled={isLoading}
        placeholder='Select mode'
        open={open}
        onSelectItem={onSelectItem}
        value={value}
        items={items}
        setOpen={setOpen}
        setValue={setValue}
        setItems={setItems}
        dropDownDirection={'TOP'}
        itemSeparator={true}
        listItemLabelStyle={styles().modeThermostatItemLabel}
        listItemContainerStyle={styles().modeThermostatItemContainer}
        showArrowIcon={false}
        showTickIcon={false}
        itemSeparatorStyle={styles().modeThermostatItemSeparator}
        dropDownContainerStyle={styles().modeThermostatDropDownContainer}
        textStyle={styles().modeThermostatText}
        disabledStyle={styles().modeThermostatDisabled}
        containerStyle={styles().modeThermostatContainer}
        style={styles().modeThermostatSelectButton}
      />
    </View>
  );
};
